Module llm

Module llm 

Structs

CompletionTokensDetails
FunctionCall
FunctionCall contains details about which function to call and with what arguments.
PromptTokensDetails
ToolCall
Tool call represents a function call that an LLM wants to make.
Usage
Usage metadata for a chat response.

Enums

ImageMime
The supported MIME type of an image.
StreamChunk
A streaming chunk that can be either text or a tool call event.