Enums
- Event
- Protocol events represent the various events that can occur during actor execution
- Internal
Event - Internal events that are processed within the runtime
- Streaming
Turn Result
Type Aliases
- ActorID
- Agent IDs are used to identify actors
- EventId
- Event IDs are used to correlate events with their responses
- RuntimeID
- Session IDs are used to identify sessions
- Submission
Id - Submission IDs are used to track actor tasks