Structs
- Completion
Tokens Details - Function
Call - FunctionCall contains details about which function to call and with what arguments.
- Prompt
Tokens Details - Tool
Call - Tool call represents a function call that an LLM wants to make.
- Usage
- Usage metadata for a chat response.
Enums
- Image
Mime - The supported MIME type of an image.
- Stream
Chunk - A streaming chunk that can be either text or a tool call event.