Module protocol

Module protocol 

Enums

Event
Protocol events represent the various events that can occur during actor execution
InternalEvent
Internal events that are processed within the runtime
StreamingTurnResult

Type Aliases

ActorID
Agent IDs are used to identify actors
EventId
Event IDs are used to correlate events with their responses
RuntimeID
Session IDs are used to identify sessions
SubmissionId
Submission IDs are used to track actor tasks